# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:06:32+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class NetModel(BaseModel):
    cidr: Optional[str] = None
    name: Optional[str] = None
    handle: Optional[str] = None
    range: Optional[str] = None
    description: Optional[str] = None
    country: Optional[str] = None
    state: Optional[str] = None
    city: Optional[str] = None
    address: Optional[str] = None
    postal_code: Optional[str] = None
    emails: Optional[List[str]] = None
    created: Optional[str] = None
    updated: Optional[str] = None


class WHOISLookupModel(BaseModel):
    host: Optional[str] = None
    nets: Optional[List[NetModel]] = None



